some_pkg package
================

Submodules
----------

.. toctree::

   some_pkg.other_mod
   some_pkg.some_mod

Module contents
---------------

.. automodule:: some_pkg
    :members:
    :undoc-members:
    :show-inheritance:
